pub struct CfgModule { /* private fields */ }Expand description
CFG module for control flow analysis.
Examples
use forge_core::Forge;
let cfg = forge.cfg();
// Enumerate paths
let symbol_id = forge_core::types::SymbolId(1);
let paths = cfg.paths(symbol_id).execute().await?;Implementations
Sourceimpl CfgModule
impl CfgModule
Sourcepub async fn index(&self) -> Result<()>
pub async fn index(&self) -> Result<()>
Indexes the codebase for CFG analysis.
Extracts CFG from C and Java source files using tree-sitter.
Returns
Ok(()) on success, or an error if indexing fails.
Sourcepub async fn extract_function_cfg(
&self,
file_path: &Path,
function_name: &str,
) -> Result<Option<TestCfg>>
pub async fn extract_function_cfg( &self, file_path: &Path, function_name: &str, ) -> Result<Option<TestCfg>>
Extract CFG for a specific function from source
Sourcepub fn paths(&self, _function: SymbolId) -> PathBuilder
pub fn paths(&self, _function: SymbolId) -> PathBuilder
Sourcepub async fn dominators(&self, _function: SymbolId) -> Result<DominatorTree>
pub async fn dominators(&self, _function: SymbolId) -> Result<DominatorTree>
Computes dominators for a function.
Uses iterative dataflow analysis to compute the dominator tree. For C/Java functions, extracts real CFG using tree-sitter.
Arguments
function- The function symbol ID