DominatorTree

Struct DominatorTree 

pub struct DominatorTree {
    pub root: BlockId,
    pub dominators: HashMap<BlockId, BlockId>,
}
Result of dominance analysis.

Fields

root: BlockId

The entry block of the function

dominators: HashMap<BlockId, BlockId>

Dominator relationships: block -> immediate dominator

Implementations

Source

impl DominatorTree

pub fn new(root: BlockId) -> Self

Creates a new empty dominator tree with the given root.

pub fn immediate_dominator(&self, block: BlockId) -> Option<BlockId>

Returns the immediate dominator of a block, if any.

pub fn dominates(&self, dominator: BlockId, block: BlockId) -> bool

Returns true if dominator dominates block.

pub fn insert(&mut self, block: BlockId, dominator: BlockId)

Adds a dominator relationship.

pub fn len(&self) -> usize

Returns the number of blocks in the dominator tree.

pub fn is_empty(&self) -> bool

Returns true if the tree has no relationships.