ForgeConn

Enum ForgeConn 

pub enum ForgeConn<'a> {
    Pool(PoolConnection<Postgres>),
    Tx(MutexGuard<'a, Transaction<'static, Postgres>>),
}
Connection wrapper that implements sqlx’s Executor trait with automatic db.query tracing spans.

Obtain via ctx.conn().await? in mutation handlers. Works with compile-time checked macros via &mut conn.

let mut conn = ctx.conn().await?;
sqlx::query_as!(User, "SELECT * FROM users WHERE id = $1", id)
    .fetch_one(&mut *conn)
    .await?

Variants

Methods from Deref<Target = PgConnection>

pub fn server_version_num(&self) -> Option<u32>

the version number of the server in libpq format

pub async fn copy_in_raw( &mut self, statement: &str, ) -> Result<PgCopyIn<&mut PgConnection>, Error>

Issue a COPY FROM STDIN statement and transition the connection to streaming data to Postgres. This is a more efficient way to import data into Postgres as compared to INSERT but requires one of a few specific data formats (text/CSV/binary).

If statement is anything other than a COPY ... FROM STDIN ... command, an error is returned.

Command examples and accepted formats for COPY data are shown here: https://www.postgresql.org/docs/current/sql-copy.html

Note

PgCopyIn::finish or PgCopyIn::abort must be called when finished or the connection will return an error the next time it is used.

pub async fn copy_out_raw<'c>( &'c mut self, statement: &str, ) -> Result<Pin<Box<dyn Stream<Item = Result<Bytes, Error>> + Send + 'c>>, Error>

Issue a COPY TO STDOUT statement and transition the connection to streaming data from Postgres. This is a more efficient way to export data from Postgres but arrives in chunks of one of a few data formats (text/CSV/binary).

If statement is anything other than a COPY ... TO STDOUT ... command, an error is returned.

Note that once this process has begun, unless you read the stream to completion, it can only be canceled in two ways:

  1. by closing the connection, or:
  2. by using another connection to kill the server process that is sending the data as shown in this StackOverflow answer.

If you don’t read the stream to completion, the next time the connection is used it will need to read and discard all the remaining queued data, which could take some time.

Command examples and accepted formats for COPY data are shown here: https://www.postgresql.org/docs/current/sql-copy.html