pub struct HttpClient { /* private fields */ }Expand description
HTTP client facade that routes requests through a circuit breaker and can apply a default timeout to requests that do not set one explicitly.
Implementations
Sourceimpl HttpClient
impl HttpClient
Sourcepub fn new(
circuit_breaker: CircuitBreakerClient,
default_timeout: Option<Duration>,
) -> Self
pub fn new( circuit_breaker: CircuitBreakerClient, default_timeout: Option<Duration>, ) -> Self
Create a new HTTP client facade.
Sourcepub fn circuit_breaker(&self) -> &CircuitBreakerClient
pub fn circuit_breaker(&self) -> &CircuitBreakerClient
Get the underlying circuit breaker client.
Sourcepub fn default_timeout(&self) -> Option<Duration>
pub fn default_timeout(&self) -> Option<Duration>
Get the default timeout applied to requests that do not override it.
Sourcepub fn request<U: IntoUrl>(&self, method: Method, url: U) -> HttpRequestBuilder
pub fn request<U: IntoUrl>(&self, method: Method, url: U) -> HttpRequestBuilder
Create a request builder.
pub fn get<U: IntoUrl>(&self, url: U) -> HttpRequestBuilder
pub fn post<U: IntoUrl>(&self, url: U) -> HttpRequestBuilder
pub fn put<U: IntoUrl>(&self, url: U) -> HttpRequestBuilder
pub fn patch<U: IntoUrl>(&self, url: U) -> HttpRequestBuilder
pub fn delete<U: IntoUrl>(&self, url: U) -> HttpRequestBuilder
pub fn head<U: IntoUrl>(&self, url: U) -> HttpRequestBuilder