pub struct McpContent {
pub uri: String,
pub name: String,
pub description: Option<String>,
pub mime_type: Option<String>,
}Expand description
Resource link content for MCP tool results.
Fields
uri: Stringname: Stringdescription: Option<String>mime_type: Option<String>Trait Implementations
Sourceimpl Clone for McpContent
impl Clone for McpContent
Sourcefn clone(&self) -> McpContent
fn clone(&self) -> McpContent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for McpContent
impl Debug for McpContent
Sourceimpl<'de> Deserialize<'de> for McpContent
impl<'de> Deserialize<'de> for McpContent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for McpContent
impl JsonSchema for McpContent
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for McpContent
impl RefUnwindSafe for McpContent
impl Send for McpContent
impl Sync for McpContent
impl Unpin for McpContent
impl UnsafeUnpin for McpContent
impl UnwindSafe for McpContent