pub struct Forge { /* private fields */ }Expand description
Main entry point for ForgeKit SDK.
The Forge type provides access to all code intelligence modules.
Implementations
Sourceimpl Forge
impl Forge
Sourcepub async fn open_with_backend(
path: impl AsRef<Path>,
backend: BackendKind,
) -> Result<Self>
pub async fn open_with_backend( path: impl AsRef<Path>, backend: BackendKind, ) -> Result<Self>
Sourcepub fn backend_kind(&self) -> BackendKind
pub fn backend_kind(&self) -> BackendKind
Returns the backend kind currently in use.
Sourcepub fn graph(&self) -> GraphModule
pub fn graph(&self) -> GraphModule
Returns the graph module for symbol and reference queries.
Sourcepub fn search(&self) -> SearchModule
pub fn search(&self) -> SearchModule
Returns the search module for semantic code queries.
Sourcepub fn edit(&self) -> EditModule
pub fn edit(&self) -> EditModule
Returns the edit module for span-safe refactoring.
Sourcepub fn analysis(&self) -> AnalysisModule
pub fn analysis(&self) -> AnalysisModule
Returns the analysis module for combined operations.