pub struct TestDatabase { /* private fields */ }Expand description
Database access for tests.
Implementations
Sourceimpl TestDatabase
impl TestDatabase
pub async fn from_url(url: &str) -> Result<Self>
Sourcepub async fn from_env() -> Result<Self>
pub async fn from_env() -> Result<Self>
Connect using TEST_DATABASE_URL, or start a container if the
testcontainers feature is enabled and the var is unset.
pub fn pool(&self) -> &PgPool
pub fn url(&self) -> &str
Sourcepub async fn isolated(&self, test_name: &str) -> Result<IsolatedTestDb>
pub async fn isolated(&self, test_name: &str) -> Result<IsolatedTestDb>
Create a dedicated database for a single test, providing full isolation.