MockHttp

Struct MockHttp 

pub struct MockHttp { /* private fields */ }
Mock HTTP client for testing.

Mocks are matched first-registered-wins: the first handler whose pattern matches the request URL (or path) is used. Register specific patterns before broad wildcards.

Patterns are matched against both the full URL and the path component, so "/health" matches a request to https://internal:8080/health.

Implementations

Source

impl MockHttp

pub fn new() -> Self

pub fn builder() -> MockHttpBuilder

pub fn add_mock_sync<F>(&self, pattern: &str, handler: F)
where F: Fn(&MockRequest) -> MockResponse + Send + Sync + 'static,

Add a mock handler (sync version for use in builders).

The pattern supports * as a glob wildcard. Mocks are matched first-registered-wins against both the full URL and the path.

pub fn mock_exact<F>(&self, url: &str, handler: F)
where F: Fn(&MockRequest) -> MockResponse + Send + Sync + 'static,

No wildcards; use mock_glob for patterns.

pub fn mock_glob<F>(&self, pattern: &str, handler: F)
where F: Fn(&MockRequest) -> MockResponse + Send + Sync + 'static,

Add a mock handler with glob pattern (* matches any substring).

Register specific patterns before broad ones — first match wins.

pub fn add_mock_boxed(&mut self, pattern: &str, handler: BoxedHandler)

pub async fn execute(&self, request: MockRequest) -> MockResponse

pub fn requests(&self) -> Vec<RecordedRequest>

pub fn requests_blocking(&self) -> Vec<RecordedRequest>

pub fn requests_to(&self, pattern: &str) -> Vec<RecordedRequest>

pub fn clear_requests(&self)

pub fn clear_mocks(&self)

pub fn assert_called(&self, pattern: &str)

Assert that a URL pattern was called.

pub fn assert_called_times(&self, pattern: &str, expected: usize)

Assert that a URL pattern was called a specific number of times.

pub fn assert_not_called(&self, pattern: &str)

Assert that a URL pattern was not called.

pub fn assert_called_with_body<F>(&self, pattern: &str, predicate: F)
where F: Fn(&Value) -> bool,

Assert that a request was made with specific body content.