Module treesitter

Module treesitter 

Tree-sitter based CFG extraction for C, Java, and Rust

This module provides real control flow graph extraction using tree-sitter parsers. Supports C, Java, and Rust languages with full CFG construction.

Structs

CfgExtractor
CFG extractor using tree-sitter
FunctionInfo
Extracted function information

Enums

SupportedLanguage
Language supported for CFG extraction