pub enum Algorithm {
Dds(Dds),
Sce(Sce),
De(De),
Pso(Pso),
}Expand description
A configured algorithm, for code that selects one at runtime (mirrors the CLI / client use where the optimizer is chosen by a flag).
Variants