Tree-sitter based CFG extraction for C, Java, and Rust
This module provides real control flow graph extraction using tree-sitter parsers. Supports C, Java, and Rust languages with full CFG construction.
Structs
- CfgExtractor
- CFG extractor using tree-sitter
- Function
Info - Extracted function information
Enums
- Supported
Language - Language supported for CFG extraction